Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(75)

Unified Diff: runtime/vm/flow_graph_allocator.h

Issue 13471013: Flow graph SIMD changes (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | runtime/vm/flow_graph_allocator.cc » ('j') | runtime/vm/flow_graph_allocator.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/flow_graph_allocator.h
diff --git a/runtime/vm/flow_graph_allocator.h b/runtime/vm/flow_graph_allocator.h
index 526db56a66fcd7343b14848fc9a3c6d31f73f185..5268c312b6bf0dfce9fac36b409c3697eccbdbee 100644
--- a/runtime/vm/flow_graph_allocator.h
+++ b/runtime/vm/flow_graph_allocator.h
@@ -37,8 +37,8 @@ class ReachingDefs : public ValueObject {
class FlowGraphAllocator : public ValueObject {
public:
- // Number of stack slots needed for a double spill slot.
- static const intptr_t kDoubleSpillSlotFactor = kDoubleSize / kWordSize;
+ // Number of stack slots needed for a fpu register spill slot.
+ static const intptr_t kFpuRegisterSpillFactor = kFpuRegisterSize / kWordSize;
explicit FlowGraphAllocator(const FlowGraph& flow_graph);
« no previous file with comments | « no previous file | runtime/vm/flow_graph_allocator.cc » ('j') | runtime/vm/flow_graph_allocator.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698